﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Telerik.Pivot.Adomd;
using Telerik.Pivot.Core.Filtering;
using Telerik.Pivot.Core.Olap;

namespace RadPivotGrid_WPF_838753
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            OlapSetCondition condition = new OlapSetCondition();
            condition.Comparison = Telerik.Pivot.Core.Filtering.SetComparison.DoesNotInclude;
            condition.Items.Add("[Sales Territory].[Sales Territory Group].&[North America]");
            var rowDescription = new AdomdGroupDescription();
            OlapLabelGroupFilter labelGroupFilter = new OlapLabelGroupFilter();
            labelGroupFilter.Condition = condition;
            rowDescription.MemberName = "[Sales Territory].[Sales Territory Group]";
            rowDescription.GroupFilter = labelGroupFilter;

            var provider = this.radPivotFieldList.DataProvider as AdomdDataProvider;

            provider.RowGroupDescriptions.Add(rowDescription);

            // Handle GetDescriptionsDataAsyncCompleted and StatusChanged in order to check for errors.
            provider.FieldDescriptionsProvider.GetDescriptionsDataAsyncCompleted += FieldDescriptionsProvider_GetDescriptionsDataAsyncCompleted;
            provider.StatusChanged += AdomdDataProvider_StatusChanged;
            
            // Handle the PrepareDescriptionForFieldEvent in order to add your filter when the user drags the dimension from the FieldList tree (at the top)
            // to rows or columns.
            provider.PrepareDescriptionForField += provider_PrepareDescriptionForField;
        }

        /// <summary>
        /// Handler for PrepareDescriptionForField event. The event is raised when user drags an item from the top of RadPivotFieldList to one of the groups below (Rows, Columns, Report Filter, Values).
        /// </summary>
        /// <param name="sender">The provider, in this case it will be AdomdDataProvider</param>
        /// <param name="e">Event arguments</param>
        void provider_PrepareDescriptionForField(object sender, Telerik.Pivot.Core.PrepareDescriptionForFieldEventArgs e)
        {
            if (e.DescriptionType == Telerik.Pivot.Core.DataProviderDescriptionType.Group)
            {
                var description = e.Description as AdomdGroupDescription;

                // Add the filter only for this Member
                if (description.MemberName == "[Sales Territory].[Sales Territory Group]")
                {
                    OlapSetCondition condition = new OlapSetCondition();
                    condition.Comparison = Telerik.Pivot.Core.Filtering.SetComparison.DoesNotInclude;
                    condition.Items.Add("[Sales Territory].[Sales Territory Group].&[North America]");
                    OlapLabelGroupFilter labelGroupFilter = new OlapLabelGroupFilter();
                    labelGroupFilter.Condition = condition;
                    description.GroupFilter = labelGroupFilter;
                }
            }
        }

        void FieldDescriptionsProvider_GetDescriptionsDataAsyncCompleted(object sender, Telerik.Pivot.Core.Fields.GetDescriptionsDataCompletedEventArgs e)
        {
            if (e.Error != null)
            {
                MessageBox.Show(e.Error.ToString());
            }
        }

        private void AdomdDataProvider_StatusChanged(object sender, Telerik.Pivot.Core.DataProviderStatusChangedEventArgs e)
        {
            if (e.Error != null)
            {
                MessageBox.Show(e.Error.ToString());
            }
        }
    }
}
